%define anolis_release 5
Name:           e2fsprogs 
Version:        1.46.5 
Release:        %{anolis_release}%{?dist}
Summary:        Utilities for managing ext2, ext3, and ext4 file systems 
License:        GPLv2 
URL:            http://%{name}.sourceforge.net/
Source0:        https://www.kernel.org/pub/linux/kernel/people/tytso/%{name}/v%{version}/%{name}-%{version}.tar.xz

Patch1:         0001-change-to-use-fuse3.patch
Patch2:         0002-Disable-metadata_csum-for-ext4-by-default-until-upst.patch

BuildRequires:  pkgconfig, texinfo, libselinux-devel, gcc, fuse-devel 
BuildRequires:  libsepol-devel, libblkid-devel, libuuid-devel
BuildRequires:  gettext, systemd, make, gnupg2, xz, autoconf

Requires:       %{name}-libs = %{version}-%{release}
Requires:       libcom_err = %{version}-%{release}
Requires:       libss = %{version}-%{release}

Obsoletes: e4fsprogs < %{version}-%{release}
Provides: e4fsprogs = %{version}-%{release}

%description

The %{name} package is a set of utilities for maintaining the ext2, ext3 and 
ext4 file systems. It provides various functionality such as creating, checking, 
modifying and repairing any corruptions. To describe the ultilities in detail, 
there is e2fsck (used to repair file system inconsistencies after an unclean 
shutdown), mke2fs (used to initialize a partition to contain an empty ext2 file 
system), debugfs (used to examine the internal structure of a file system, to 
manually repair a corrupted file system, or to create test cases for e2fsck), 
tune2fs (used to modify file system parameters), and most of the other core 
ext2fs file system utilities.

In order to tune the performance of an ext2, ext3, or ext4 file system, it is
recommended that you install the %{name} package.

%package libs
Summary: shared libraries specifically for Ext2/3/4 file system
License: GPLv2 and LGPLv2
Requires: libcom_err = %{version}-%{release}

%description libs
%{name}-libs contains the libraries of the %{name} package,
libe2p and libext2fs, which are used to directly access ext2/3/4 file systems
from user space.

%package static
Summary: Ext2/3/4 file system specific static libraries
License: GPLv2 and LGPLv2

%description static
E2fsprogs-static contains all static libraries built from %{name},
including libext2fs, libcom_err, libe2p, and libss.

These libraries are used to directly access ext2/3/4 file systems
from user space, and perform other useful functions.

%package devel
Summary: Ext2/3/4 file system specific libraries and headers
License: GPLv2 and LGPLv2
Requires: pkgconfig gawk libcom_err-devel = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}

%description devel

The %{name}-devel package provides the libraries and header files required to 
develop programs that interact with ext2, ext3, and ext4 file systems. These 
libraries include functions for reading and writing data to and from these file 
systems, as well as functions for managing file system metadata such as inodes 
and directories. By using these libraries, developers can create custom tools 
that interact with ext2/3/4 file systems in a variety of ways.

If you’re interested in developing software that interacts with these file 
systems, you should definitely install %{name}-devel together with %{name}.

%package -n libcom_err
Summary: Common error description library
License: MIT

%description -n libcom_err
This is the common error description library, part of %{name}.

libcom_err is an attempt to present a common error-handling mechanism.

%package -n libcom_err-devel
Summary: Common error description library
License: MIT
Requires: libcom_err = %{version}-%{release} pkgconfig

%description -n libcom_err-devel

libcom_err-devel contains the common error description development library and 
headers, which are part of %{name}. The library contains the compile_et 
command which is used to convert a table listing error-code names and 
associated messages into a C source file suitable for use with the library. 
libcom_err is an attempt to present a common error-handling mechanism. 

It is a common error description library that presents a mechanism to manipulate 
the most common form of error code in a fashion that does not have the problems 
identified with mechanisms commonly in use.

%package -n libss
Summary: Command line interface parsing library
License: MIT
Requires: libcom_err = %{version}-%{release}

%description -n libss
This is a description of libss, a command line interface parsing library, 
which is part of %{name}. 

The package includes a tool that parses a command table to generate a simple 
command-line interface parser, the include files needed to compile and use it. 

It was originally inspired by the Multics SubSystem library.

%package -n libss-devel
Summary: Command line interface parsing library
License: MIT
Requires: libss = %{version}-%{release} pkgconfig

%description -n libss-devel
libss-devel is a command line interface parsing library that is part of 
%{name}. It contains the mk_cmds command, which generates a simple 
command-line interface parser by parsing a command table. 

This library was inspired by the Multics SubSystem library.

%package -n e2scrub
Summary: Online Ext4 metadata consistency checking tool and service
License: GPLv2 and LGPLv2
Recommends: sendmail
Requires: systemd util-linux lvm2 %{name} = %{version}-%{release}

%description -n e2scrub
This package includes e2scrub script that can check ext[234] file system
metadata consistency while the file system is online. It also containes a
systemd service that can be enabled to do consistency check periodically.

The file system consistency check can be performed online and does not
require the file system to be unmounted. It uses lvm snapshots to do this
which means that it can only be done on file systems that are on a lvm
managed device with some free space available in respective volume group.

%prep
%autosetup -p1

rm -f configure
autoconf
rm -rf tests/m_rootdir_acl

%global _udevdir %{_prefix}/lib/udev/rules.d

%build
%global optflags %{optflags} -I%{_includedir}/fuse3
%configure --enable-quota --with-root-prefix=/usr --with-crond-dir=no \
           --disable-e2initrd-helper --disable-libblkid --disable-libuuid \
           CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing" \
           --enable-elf-shlibs --enable-nls --disable-uuidd --disable-fsck
           
%make_build

%install
rm -rf $RPM_BUILD_ROOT
export PATH=/sbin:$PATH
%make_install install-libs root_libdir=%{_libdir} root_sbindir=%{_sbindir} 
chmod +w %{buildroot}%{_libdir}/*.a

%find_lang %{name}

%generate_compatibility_deps

%check
make PRINT_FAILED=yes fullcheck

%ldconfig_scriptlets -n libss
%ldconfig_scriptlets -n libcom_err
%ldconfig_scriptlets libs

%files -f %{name}.lang
%doc README
%{!?_licensedir:%global license %%doc}

%config(noreplace) %{_sysconfdir}/mke2fs.conf
%{_bindir}/chattr
%{_bindir}/lsattr
%{_bindir}/fuse2fs
%exclude %{_mandir}/man8/e2scrub*
%exclude %{_sbindir}/e2scrub*
%{_sbindir}/*
%{abidir}/debugfs-option.list
%{abidir}/e4crypt-option.list
%{_mandir}/man8/*
%{_mandir}/man5/*
%{_mandir}/man1/lsattr.1*
%{_mandir}/man1/fuse2fs.1*
%{_mandir}/man1/chattr.1*

%exclude %{_libdir}/%{name}/e2scrub_all_cron

%files libs
%dir %{abidir}
%{abidir}/libext2fs.dump
%{abidir}/libe2p.dump
%{_libdir}/libext2fs.so.*
%{_libdir}/libe2p.so.*
%license NOTICE
%{!?_licensedir:%global license %%doc}

%files static
%{!?_licensedir:%global license %%doc}
%license NOTICE
%{_libdir}/*.a

%files devel
%{_includedir}/e2p
%{_includedir}/ext2fs
%{_libdir}/pkgconfig/ext2fs.pc
%{_libdir}/pkgconfig/e2p.pc
%{_libdir}/libext2fs.so
%{_libdir}/libe2p.so
%{_infodir}/libext2fs.info*

%files -n libcom_err
%{!?_licensedir:%global license %%doc}
%license NOTICE
%{_libdir}/libcom_err.so.*
%{abidir}/libcom_err.dump

%files -n libcom_err-devel
%{_libdir}/pkgconfig/com_err.pc
%{_mandir}/man3/com_err.3*
%{_mandir}/man1/compile_et.1*
%{_includedir}/com_err.h
%{_includedir}/et
%{_datadir}/et
%{_libdir}/libcom_err.so
%{_bindir}/compile_et

%files -n libss
%{!?_licensedir:%global license %%doc}
%license NOTICE
%{_libdir}/libss.so.*
%{abidir}/libss.dump

%files -n libss-devel
%{_libdir}/pkgconfig/ss.pc
%{_mandir}/man1/mk_cmds.1*
%{_includedir}/ss
%{_datadir}/ss
%{_libdir}/libss.so
%{_bindir}/mk_cmds

%files -n e2scrub
%{_udevdir}/96-e2scrub.rules
%{_unitdir}/e2scrub*
%{_libdir}/%{name}/e2scrub_fail
%{_mandir}/man8/e2scrub*
%{_sbindir}/e2scrub_all
%{_sbindir}/e2scrub
%config(noreplace) %{_sysconfdir}/e2scrub.conf

%changelog
* Wed Apr 12 2023 Zhongling <zhonglingh@linux.alibaba.com> - 1.46.5-5
- Refactor rpm spec

* Tue Nov 15 2022 ZiyangZhang <ZiyangZhang@linux.alibaba.com> - 1.46.5-4
- Disable metadata_csum for ext4 by default until upstream fix perf loss

* Mon Oct 31 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.46.5-3
- optimise spec file 

* Tue Mar 22 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.46.5-2
- change to fuse3

* Tue Mar 08 2022 pangqing <pangqing@uniontech.com> - 1.46.5-1
- Init for anolisOS 23

